package WWW::ShopBot::_test;

sub query {
[
 {
     product => 'aaa',
     price => 1234,
 },
 {
    product =>'asdf',
    price   => 123,
},
 {
     product => 'qwer',
     price => 12345,
 },
 ]
}

1;
__END__
# Below is stub documentation for your module. You better edit it!

=head1 NAME

WWW::ShopBot::_test - A testing module for WWW::ShopBot

=head1 DESCRIPTION

It is a testing module for WWW::ShopBot and for testing only. Please do not modify this submodule or use it.

=head1 AUTHOR

xern, E<lt>xern@cpan.orgE<gt>

=cut
